# boilerdaq

[![All Contributors](https://img.shields.io/github/all-contributors/softboiler/boilerdaq?color=ee8449&style=flat-square)](#contributors)

Data acquisition for a nucleate pool boiling experimental apparatus.

## Project information

- [Changes](<https://softboiler.github.io/boilerdaq/changelog.html>)
- [Docs](<https://softboiler.github.io/boilerdaq>)
- [Contributing](<https://softboiler.github.io/boilerdaq/contributing.html>)

## Contributors

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- ALL-CONTRIBUTORS-LIST:END -->
